@@ -1,10 +1,10 @@
---- ruby-nusdas-0.8.orig/extconf.rb
-+++ ruby-nusdas-0.8/extconf.rb
+--- ruby-nusdas.orig/extconf.rb
++++ ruby-nusdas/extconf.rb
 @@ -1,6 +1,6 @@
  require "mkmf"
  
 -dir_config('narray',$sitearchdir,$sitearchdir)
-+dir_config('narray',$archdir,$archdir)
++dir_config('narray',$vendorarchdir,$vendorarchdir)
  dir_config('nusdas','/usr/local')
  
  if ( ! ( have_header("narray.h") && have_header("narray_config.h") ) ) then
